function [T,tou,Tb,dnodtvt]=Tadiabatic1(p,Tu,phi,f,Trange,CR,fueltype);
% 
% Written By Talal Yusaf
% 
% Modified By Daniel Bichel
% 
% Last Modified 26 October 2007
% 
% 
% Tb=Tadiabatic(p,Tu,phi,f,fueltype,airscheme)
%
% Routine for calculating the adiabatic flame temperature.
% Method involves iteratively selecting flame temperatures until
% the enthalpy of the combustion products (in equilibrium) matches
% the enthalpy of the initial gas mixture.  
% farg.m is used to determine the enthalpy of the unburned mixture, 
% and ecp.m is used to determine the enthalpy of the burned gas.
% Also used to determine the initial formation rate of NO and the 
% characteristic time.
% ********************************************************************
% input: 
% p - pressure (Pa)
% Tu - temperature of the unburned mixture (K)
% phi - equivalence ratio
% f - residual mass fraction; set f=0 if no combustion products 
% are present and f=1 if only combustion products are present  
% fueltype - 'gasoline', 'diesel', etc - see fueldata.m for full list
% airscheme - 'GMcB' (Gordon and McBride) or 'Chemkin'
% CR - compression ratio
% Trange - temperature range for the evaluation of NO formation and 
% characteristic time
% output: 
% Tb - temperature of the burned gas (K) - adiabatic flame temperature
% Formation rate of NO graph across the evaluated temperature
% Characteristic time graph across the evaluated temperature 
% ********************************************************************
clc

airscheme='Chemkin';%airscheme type
thi=phi;
P1=1;%inlet pressure in BAR
MWN2=28.013;%Molecular weight of N2
MWO2=31.999;%Molecular weight of O2\

MaxIter=50;
Tol=0.00001; % 0.001% allowable error in temperature calculation
Tb=2000; % initial estimate
DeltaT=2*Tol*Tb; % something big
Iter=0;
[hu,u,v,s,Y,cp,dlvlT,dlvlp]=farg1(p,Tu,phi,f,fueltype,airscheme);

while (Iter<MaxIter)&(abs(DeltaT/Tb)>Tol)
   Iter=Iter+1;
   [x,hb,u,v,s,Y,cp,dlvlT,dlvlp]=ecp1(p,Tb,phi,fueltype,airscheme);
   DeltaT=(hu-hb)/cp;
   Tb=Tb+DeltaT;
end

if Iter>=MaxIter
   warning('convergence failure in adiabatic flame temperature loop');
end

x3=x(3,1)/MWO2;%02 fraction (Y) in mol/g
x2=x(2,1)/MWN2;%N2 fraction
x8=x(8,1);%NO fraction
P=P1*(CR)^1.4;
MWNO=.5*MWO2+.5*MWN2;
x10=x(10,1)/MWNO;



for k=1:(1+Trange)
    T=(k+1899);%temperature range from 1900 to 1900+Trange
    
    %initial formation rate of NO (dondtvt)
    dnodtvt(k)=((6*10^16)/(T^(1/2)))*exp(-69090/T)*x3^(1/2)*x2;
    
    %characteristic time (tou)   
    tou1=(8*10^(-16)*T*exp(58300/T))/(P^(1/2))*100;%time is in seconds, so divide it by 100 as P is in BAR ie 1000/100000
    tou(k)=1/tou1;
        
end
T=[1900:1:(1900+Trange)];


%Optional Graphing commands
% figure(1);
% semilogy(T,dnodtvt,'y');
% xlabel('Temperature (K)');
% ylabel('Formation rate of NO')
% title('NO formation rate Vs Temperature');
% hold on
% 
% % figure(2);
% plot(T,tou,'k');
% xlabel('Temperature');
% ylabel('Characteristic time (ms) ');
% title('Characteristic time Vs Temperature');
% hold on
% 
% figure(3);
% plot(phi,Tb,'r*');
% hold on
% xlabel('Equivalence ratio (thi)');
% ylabel('Adiabatic flame temperature (K)');
% title('Flame temperature Vs Equivalence ratio');
